<template>
	<div class="pc-prompts">
		<div class="title flex items-center justify-between">
			<div class="flex item-center">
				<span>提问示例</span>
				<span class="split"></span>
				<span class="change cursor-pointer" @click="advanceExampleClick">高级示例 ></span>
			</div>
			<div class="cursor-pointer" @click="batchChange">
				<span class="mr-1 changeBatch">换一批</span>
				<i class="myiconfont icon-shuaxin"></i>
			</div>
		</div>
		<div class="main">
			<el-carousel height="80" :interval="6000" indicator-position="none">
				<el-carousel-item v-for="(group, index) in state.m_groupArr" :key="index" class="set-carousel-item">
					<div
						class="main_item flex items-center cursor-pointer"
						v-for="(item, index) in group"
						:key="index"
						:class="{ main_item_active: item.sample_id === activeSampleId }"
						@click="changeExample(item)"
					>
						<div class="left flex items-center justify-center" :class="['color' + index]">
							<img :src="item.Icon" alt="" />
						</div>
						<div class="right">
							<h4>{{ item.sample_title }}</h4>
							<p>{{ item.sample_question }}</p>
						</div>
					</div>
				</el-carousel-item>
			</el-carousel>
		</div>
	</div>
</template>

<script setup lang="ts">
import { reactive } from 'vue';
import { activeRoomId, activeSampleId, setRoomConfig } from '/@/stores/chatRoom';
let state = reactive({
	exampleContent: [],
	isShowExample: false,
	m_groupArr: [],
});
const emits = defineEmits<{
	(event: 'advanceExampleClick', data): void;
	(event: 'updateChatInput', val): void;
}>();
const props = defineProps(['exampleList']);

const initGroupedArr = () => {
	const groups = [];
	let i = 0;
	while (state.exampleContent.length > i) {
		groups.push(state.exampleContent.slice(i, (i += 4)));
	}

	state.m_groupArr = groups;
};

const changeExample = (item) => {
	emits('updateChatInput', item.sample_question);
	setRoomConfig(activeRoomId.value, 'isAnswerByLLM', false);
	activeSampleId.value = item.sample_id;
	// topGroupId.value = item.section_a_id;
};
//换一批
const batchChange = () => {
	let groups = state.m_groupArr;
	// 打乱批次顺序
	for (let i = groups.length - 1; i > 0; i--) {
		const j = Math.floor(Math.random() * (i + 1));
		[groups[i], groups[j]] = [groups[j], groups[i]];
	}
	state.m_groupArr = groups;
};
//打开高级示例
const advanceExampleClick = () => {
	emits('advanceExampleClick', true);
};
const tagListClick = (tagList) => {
	let result = [];
	tagList.forEach((tag) => {
		props.exampleList.forEach((sample) => {
			if (tag == sample.group_id) {
				result.push(sample);
			}
		});
	});
	state.exampleContent = result;
	initGroupedArr();
};
defineExpose({
	tagListClick,
});
</script>
<style scoped lang="scss">
.pc-prompts {
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
	margin-top: 40px;
	width: 760px;
	padding: 0;
	font-size: 14px;
	.title {
		color: #999;
		line-height: 14px;
		.split {
			height: 12px;
			width: 2px;
			background-color: #ccc;
			margin: 0 10px;
		}
		span {
			color: rgb(32, 33, 35);
			font-size: 14px;
		}
		.changeBatch {
			color: #999;
			font-size: 12px;
			transition: color 0.2s ease-in-out;
		}
		.change {
			color: #999;
			transition: color 0.2s ease-in-out;
		}
	}
	.main {
		width: calc(100% + 16px);
		display: flex;
		flex-wrap: wrap;
		margin: 4px -8px 0;
		&_item {
			box-sizing: border-box;
			width: calc(50% - 16px);
			margin: 8px;
			padding: 12px;
			height: 84px;
			border: 1px solid #d9dbde;
			border-radius: 5px;
			background-color: transparent;
			-webkit-transition: border-color 0.2s, background-color 0.2s;
			-o-transition: border-color 0.2s, background-color 0.2s;
			transition: border-color 0.2s, background-color 0.2s;

			.left {
				width: 50px;
				height: 50px;
				border-radius: 5px;
			}
			.color0 {
				background: linear-gradient(180deg, #f63c8b, #fd216c);
			}
			.color1 {
				background: linear-gradient(180deg, #0ebfe1, #0ab2d3);
			}
			.color2 {
				background: linear-gradient(180deg, #9647fe, #7b5be8);
			}
			.color3 {
				background: linear-gradient(180deg, #fb894c, #ff7958);
			}
			.right {
				flex: 1;
				min-width: 0;
				margin-left: 12px;
				h4 {
					color: #202123;
					font-size: 13px;
					font-weight: 500;
					height: 16px;
					transition: background-color 0.2s;
					overflow: hidden;
					text-overflow: ellipsis;
					white-space: nowrap;
				}
				p {
					font-size: 12px;
					margin-top: 6px;
					height: 34px;
					line-height: 17px;
					color: #8d8e99;
					overflow: hidden;
					-o-text-overflow: ellipsis;
					text-overflow: ellipsis;
					-webkit-line-clamp: 2;
					-webkit-box-orient: vertical;
				}
			}
		}
		&_item_active {
			border: 1px solid #007aff;
			background-color: #ebeef3;
			.right {
				h4 {
					color: #007aff;
				}
			}
		}
		.set-carousel-item {
			display: flex;
			flex-wrap: wrap;
		}
	}
}

:deep(.el-drawer__header) {
	padding: 30px 20px 26px !important;
	box-sizing: border-box;
	width: 100%;
	background-color: #e0e7fb;

	position: relative;

	height: unset !important;
	margin-bottom: unset !important;
	border-bottom: unset !important;
}
:deep(.el-drawer__body) {
	overflow-x: hidden;
}
:deep(.el-carousel--horizontal) {
	width: 100%;
}
:deep(.el-carousel__container) {
	width: 100%;
	height: 200px !important;
}
</style>
